==========
Developers
==========

**skpro** is developed open source under the direction of `Dr Franz Király`_. Check out the `public code repository`_ to learn more.

**Active contributors**

* Franz Kiraly <f.kiraly@ucl.ac.uk> [`@fkiraly <https://github.com/fkiraly>`_]: project manager and designated point of contact
* Frithjof Gressmann [`@frthjf <https://github.com/frthjf>`_]: principal developer and curator
* Vitaly Davydov [`@iwitaly <https://github.com/iwitaly>`_]: contributor


If you like to contribute, read our `contribution guide <https://github.com/sktime/skpro/CONTRIBUTING.md>`_.

.. _public code repository: https://github.com/sktime/skpro
.. _Dr Franz Király: https://www.ucl.ac.uk/statistics/people/franz-kiraly
